@@ -35,5 +35,9 @@ struct spwd *spwd;
 	    return (0);
 	}
     }
+    if (spwd->sp_lstchg == 0) {
+	printf("Your password has expired. Choose a new one.\n");
+	return (1);
+    }
     return (0);
 }
