@@ -42,7 +42,7 @@ int skeyverify __ARGS((struct skey *mp,char *response));
 
 /* Simplified application programming interface. */
 #include <pwd.h>
-int skeyaccess __ARGS((char *user, char *port, char *host, char *addr));
+int skeyaccess __ARGS((struct passwd *, char *, char *, char *));
 char *skey_getpass __ARGS((char *prompt, struct passwd *pwd, int pwok));
 char *skey_crypt __ARGS((char *pp, char *salt, struct passwd *pwd, int pwok));
 
